# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .agents_search_response_agents_item_memory_blocks_item import AgentsSearchResponseAgentsItemMemoryBlocksItem
from .agents_search_response_agents_item_memory_prompt_template import (
    AgentsSearchResponseAgentsItemMemoryPromptTemplate,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class AgentsSearchResponseAgentsItemMemory(UncheckedBaseModel):
    blocks: typing.List[AgentsSearchResponseAgentsItemMemoryBlocksItem]
    prompt_template: typing.Optional[AgentsSearchResponseAgentsItemMemoryPromptTemplate] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
