# This file was auto-generated by Fern from our API Definition.

import typing
from ...types.conditional_tool_rule import ConditionalToolRule
from ...types.child_tool_rule import ChildToolRule
from ...types.continue_tool_rule import ContinueToolRule
from ...types.terminal_tool_rule import TerminalToolRule
from ...types.init_tool_rule import InitToolRule

UpdateAgentToolRulesItem = typing.Union[
    ConditionalToolRule, ChildToolRule, ContinueToolRule, TerminalToolRule, InitToolRule
]
