# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .agents_search_response_agents_item_tools_item_tool_type import AgentsSearchResponseAgentsItemToolsItemToolType
from .agents_search_response_agents_item_tools_item_description import (
    AgentsSearchResponseAgentsItemToolsItemDescription,
)
from .agents_search_response_agents_item_tools_item_source_type import AgentsSearchResponseAgentsItemToolsItemSourceType
from .agents_search_response_agents_item_tools_item_organization_id import (
    AgentsSearchResponseAgentsItemToolsItemOrganizationId,
)
from .agents_search_response_agents_item_tools_item_name import AgentsSearchResponseAgentsItemToolsItemName
from .agents_search_response_agents_item_tools_item_source_code import AgentsSearchResponseAgentsItemToolsItemSourceCode
from .agents_search_response_agents_item_tools_item_json_schema import AgentsSearchResponseAgentsItemToolsItemJsonSchema
from .agents_search_response_agents_item_tools_item_created_by_id import (
    AgentsSearchResponseAgentsItemToolsItemCreatedById,
)
from .agents_search_response_agents_item_tools_item_last_updated_by_id import (
    AgentsSearchResponseAgentsItemToolsItemLastUpdatedById,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class AgentsSearchResponseAgentsItemToolsItem(UncheckedBaseModel):
    id: typing.Optional[str] = None
    tool_type: typing.Optional[AgentsSearchResponseAgentsItemToolsItemToolType] = None
    description: typing.Optional[AgentsSearchResponseAgentsItemToolsItemDescription] = None
    source_type: typing.Optional[AgentsSearchResponseAgentsItemToolsItemSourceType] = None
    organization_id: typing.Optional[AgentsSearchResponseAgentsItemToolsItemOrganizationId] = None
    name: typing.Optional[AgentsSearchResponseAgentsItemToolsItemName] = None
    tags: typing.Optional[typing.List[str]] = None
    source_code: typing.Optional[AgentsSearchResponseAgentsItemToolsItemSourceCode] = None
    json_schema: typing.Optional[AgentsSearchResponseAgentsItemToolsItemJsonSchema] = None
    return_char_limit: typing.Optional[float] = None
    created_by_id: typing.Optional[AgentsSearchResponseAgentsItemToolsItemCreatedById] = None
    last_updated_by_id: typing.Optional[AgentsSearchResponseAgentsItemToolsItemLastUpdatedById] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
