# This file was auto-generated by Fern from our API Definition.

import typing

TemplatesCreateAgentsResponseAgentsItemAgentType = typing.Union[
    typing.Literal["memgpt_agent", "split_thread_agent", "offline_memory_agent", "chat_only_agent"], typing.Any
]
