# This file was auto-generated by Fern from our API Definition.

import typing

TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem = typing.Union[float, typing.Optional[str]]
