# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_tool_rules_item_item import AgentsSearchResponseAgentsItemToolRulesItemItem

AgentsSearchResponseAgentsItemToolRulesItem = typing.Union[
    typing.List[AgentsSearchResponseAgentsItemToolRulesItemItem], typing.Optional[str]
]
