# This file was auto-generated by Fern from our API Definition.

import typing

NotFoundErrorBodyMessage = typing.Union[
    typing.Literal[
        "Agent provided is a template or not found, you can only migrate deployed agents",
        "Template version provided does not exist",
    ],
    typing.Any,
]
