# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .openai_types_chat_chat_completion_message_tool_call_function import (
    OpenaiTypesChatChatCompletionMessageToolCallFunction,
)
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ChatCompletionMessageToolCallInput(UncheckedBaseModel):
    id: str
    function: OpenaiTypesChatChatCompletionMessageToolCallFunction
    type: typing.Literal["function"] = "function"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
