# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_project_id_item import (
    TemplatesCreateAgentsResponseAgentsItemProjectIdItem,
)

TemplatesCreateAgentsResponseAgentsItemProjectId = typing.Union[
    str,
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsResponseAgentsItemProjectIdItem]],
    typing.Optional[typing.Any],
]
