# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_tool_exec_environment_variables_item_created_by_id_item import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem,
)

AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById = typing.Union[
    str,
    typing.Optional[str],
    typing.List[typing.Optional[AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem]],
    typing.Optional[typing.Any],
]
