# This file was auto-generated by Fern from our API Definition.

from .types import (
    TemplatesCreateAgentsResponse,
    TemplatesCreateAgentsResponseAgentsItem,
    TemplatesCreateAgentsResponseAgentsItemAgentType,
    TemplatesCreateAgentsResponseAgentsItemBaseTemplateId,
    TemplatesCreateAgentsResponseAgentsItemBaseTemplateIdItem,
    TemplatesCreateAgentsResponseAgentsItemCreatedAt,
    TemplatesCreateAgentsResponseAgentsItemCreatedAtItem,
    TemplatesCreateAgentsResponseAgentsItemCreatedById,
    TemplatesCreateAgentsResponseAgentsItemCreatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemDescription,
    TemplatesCreateAgentsResponseAgentsItemDescriptionItem,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfig,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureDeployment,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureDeploymentItem,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureEndpoint,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureEndpointItem,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureVersion,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureVersionItem,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingChunkSize,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingEndpoint,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingEndpointType,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigHandle,
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigHandleItem,
    TemplatesCreateAgentsResponseAgentsItemIdentityIds,
    TemplatesCreateAgentsResponseAgentsItemLastUpdatedById,
    TemplatesCreateAgentsResponseAgentsItemLastUpdatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemLlmConfig,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigHandle,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigHandleItem,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigMaxTokens,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigMaxTokensItem,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigModelEndpoint,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigModelEndpointItem,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigModelEndpointType,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigModelWrapper,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigModelWrapperItem,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem,
    TemplatesCreateAgentsResponseAgentsItemLlmConfigTemperature,
    TemplatesCreateAgentsResponseAgentsItemMemory,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItem,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemCreatedById,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemCreatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemDescription,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemDescriptionItem,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemId,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemIsTemplate,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLabel,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLabelItem,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLastUpdatedById,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLimit,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemMetadata,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemMetadataItem,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemName,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemNameItem,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemOrganizationId,
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemOrganizationIdItem,
    TemplatesCreateAgentsResponseAgentsItemMemoryPromptTemplate,
    TemplatesCreateAgentsResponseAgentsItemMessageBufferAutoclear,
    TemplatesCreateAgentsResponseAgentsItemMessageIds,
    TemplatesCreateAgentsResponseAgentsItemMessageIdsItem,
    TemplatesCreateAgentsResponseAgentsItemMetadata,
    TemplatesCreateAgentsResponseAgentsItemMetadataItem,
    TemplatesCreateAgentsResponseAgentsItemOrganizationId,
    TemplatesCreateAgentsResponseAgentsItemOrganizationIdItem,
    TemplatesCreateAgentsResponseAgentsItemProjectId,
    TemplatesCreateAgentsResponseAgentsItemProjectIdItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedAt,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedAtItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedById,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemDescription,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemDescriptionItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfig,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigHandle,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigHandleItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemId,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemLastUpdatedById,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemLastUpdatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemMetadata,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemMetadataItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemOrganizationId,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemOrganizationIdItem,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemUpdatedAt,
    TemplatesCreateAgentsResponseAgentsItemSourcesItemUpdatedAtItem,
    TemplatesCreateAgentsResponseAgentsItemTemplateId,
    TemplatesCreateAgentsResponseAgentsItemTemplateIdItem,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariables,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItem,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemId,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem,
    TemplatesCreateAgentsResponseAgentsItemToolRules,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItem,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMapping,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildren,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildrenType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItem,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMapping,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildren,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildrenType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemOne,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemOneType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemToolName,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemToolNameType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemTwo,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemTwoType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemOne,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemOneType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemToolName,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemToolNameType,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemTwo,
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemTwoType,
    TemplatesCreateAgentsResponseAgentsItemToolsItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemCreatedById,
    TemplatesCreateAgentsResponseAgentsItemToolsItemCreatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemDescription,
    TemplatesCreateAgentsResponseAgentsItemToolsItemDescriptionItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemJsonSchema,
    TemplatesCreateAgentsResponseAgentsItemToolsItemJsonSchemaItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemLastUpdatedById,
    TemplatesCreateAgentsResponseAgentsItemToolsItemLastUpdatedByIdItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemName,
    TemplatesCreateAgentsResponseAgentsItemToolsItemNameItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationId,
    TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationIdItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemSourceCode,
    TemplatesCreateAgentsResponseAgentsItemToolsItemSourceCodeItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemSourceType,
    TemplatesCreateAgentsResponseAgentsItemToolsItemSourceTypeItem,
    TemplatesCreateAgentsResponseAgentsItemToolsItemToolType,
    TemplatesCreateAgentsResponseAgentsItemUpdatedAt,
    TemplatesCreateAgentsResponseAgentsItemUpdatedAtItem,
)

__all__ = [
    "TemplatesCreateAgentsResponse",
    "TemplatesCreateAgentsResponseAgentsItem",
    "TemplatesCreateAgentsResponseAgentsItemAgentType",
    "TemplatesCreateAgentsResponseAgentsItemBaseTemplateId",
    "TemplatesCreateAgentsResponseAgentsItemBaseTemplateIdItem",
    "TemplatesCreateAgentsResponseAgentsItemCreatedAt",
    "TemplatesCreateAgentsResponseAgentsItemCreatedAtItem",
    "TemplatesCreateAgentsResponseAgentsItemCreatedById",
    "TemplatesCreateAgentsResponseAgentsItemCreatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemDescription",
    "TemplatesCreateAgentsResponseAgentsItemDescriptionItem",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfig",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureDeployment",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureDeploymentItem",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureEndpoint",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureEndpointItem",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureVersion",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureVersionItem",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingChunkSize",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingEndpoint",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingEndpointType",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigHandle",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigHandleItem",
    "TemplatesCreateAgentsResponseAgentsItemIdentityIds",
    "TemplatesCreateAgentsResponseAgentsItemLastUpdatedById",
    "TemplatesCreateAgentsResponseAgentsItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfig",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigHandle",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigHandleItem",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigMaxTokens",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigMaxTokensItem",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigModelEndpoint",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigModelEndpointItem",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigModelEndpointType",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigModelWrapper",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigModelWrapperItem",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigTemperature",
    "TemplatesCreateAgentsResponseAgentsItemMemory",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemCreatedById",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemCreatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemDescription",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemDescriptionItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemId",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemIsTemplate",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLabel",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLabelItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLastUpdatedById",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLimit",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemMetadata",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemMetadataItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemName",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemNameItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemOrganizationId",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemOrganizationIdItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryPromptTemplate",
    "TemplatesCreateAgentsResponseAgentsItemMessageBufferAutoclear",
    "TemplatesCreateAgentsResponseAgentsItemMessageIds",
    "TemplatesCreateAgentsResponseAgentsItemMessageIdsItem",
    "TemplatesCreateAgentsResponseAgentsItemMetadata",
    "TemplatesCreateAgentsResponseAgentsItemMetadataItem",
    "TemplatesCreateAgentsResponseAgentsItemOrganizationId",
    "TemplatesCreateAgentsResponseAgentsItemOrganizationIdItem",
    "TemplatesCreateAgentsResponseAgentsItemProjectId",
    "TemplatesCreateAgentsResponseAgentsItemProjectIdItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedAt",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedAtItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedById",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemDescription",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemDescriptionItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfig",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigHandle",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigHandleItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemId",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemLastUpdatedById",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemMetadata",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemMetadataItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemOrganizationId",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemOrganizationIdItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemUpdatedAt",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemUpdatedAtItem",
    "TemplatesCreateAgentsResponseAgentsItemTemplateId",
    "TemplatesCreateAgentsResponseAgentsItemTemplateIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariables",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemDescription",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemId",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem",
    "TemplatesCreateAgentsResponseAgentsItemToolRules",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItem",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMapping",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildren",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildrenType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItem",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMapping",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildren",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildrenType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemOne",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemOneType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemToolName",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemToolNameType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemTwo",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemTwoType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemOne",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemOneType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemToolName",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemToolNameType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemTwo",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemTwoType",
    "TemplatesCreateAgentsResponseAgentsItemToolsItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemCreatedById",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemCreatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemDescription",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemDescriptionItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemJsonSchema",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemJsonSchemaItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemLastUpdatedById",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemName",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemNameItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationId",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemSourceCode",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemSourceCodeItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemSourceType",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemSourceTypeItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemToolType",
    "TemplatesCreateAgentsResponseAgentsItemUpdatedAt",
    "TemplatesCreateAgentsResponseAgentsItemUpdatedAtItem",
]
