# This file was auto-generated by Fern from our API Definition.

import typing

TemplatesCreateAgentsResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem = typing.Union[bool, typing.Optional[str]]
