# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .templates_create_agents_response_agents_item_tool_rules_item_item_one_type import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemOneType,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemOne(UncheckedBaseModel):
    tool_name: str
    type: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemOneType] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
