# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_created_at_item import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem,
)

TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt = typing.Union[
    str,
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem]],
    typing.Optional[typing.Any],
]
